==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/icaptioninteractorstyle.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICAPTIONINTERACTORSTYLE_H
#define ICAPTIONINTERACTORSTYLE_H


#include <vtkInteractorStyleTrackballActor.h>
#include "iviewmodulecomponent.h"


class iCaption;


class iCaptionInteractorStyle: virtual public vtkInteractorStyleTrackballActor, protected iViewModuleComponent
{
	
public:
	
	static iCaptionInteractorStyle* New(iViewModule *vm);
	
	void FindPickedActor(int x, int y);
	
	void Rotate(); 
	void OnLeftButtonUp();
	void OnLeftButtonDown();
	//
	//  Disable all interactions except left mouse moving the caption around
	//
	void Spin(){} 
	void Pan(){}
	void Dolly(){} 
	void UniformScale(){}
	
	void OnChar(){}
	void OnMiddleButtonDown(){}
	void OnMiddleButtonUp(){}
	void OnRightButtonDown(){}
	void OnRightButtonUp(){}

protected:
	
	iCaptionInteractorStyle(iViewModule *vm);
	virtual ~iCaptionInteractorStyle(){}

private:

	iCaption *mInteractionCaption;
};

#endif // ICAPTIONINTERACTORSTYLE_H

==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/core/icaptioninteractorstyle.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICAPTIONINTERACTORSTYLE_H
#define ICAPTIONINTERACTORSTYLE_H


#include <vtkInteractorStyleTrackballActor.h>


#include "ipointermacro.h"

class iCaption;
class iViewModule;


class iCaptionInteractorStyle: public vtkInteractorStyleTrackballActor
{
	
	IPOINTER_AS_PART(ViewModule);

public:
	
	vtkTypeMacro(iCaptionInteractorStyle,vtkInteractorStyleTrackballActor);
	static iCaptionInteractorStyle* New(iViewModule *vm = 0);
	
	void FindPickedActor(int x, int y);
	
	void Rotate(); 
	void OnLeftButtonUp();
	void OnLeftButtonDown();
	//
	//  Disable all interactions except left mouse moving the caption around
	//
	void Spin(){} 
	void Pan(){}
	void Dolly(){} 
	void UniformScale(){}
	
	void OnChar(){}
	void OnMiddleButtonDown(){}
	void OnMiddleButtonUp(){}
	void OnRightButtonDown(){}
	void OnRightButtonUp(){}

protected:
	
	virtual ~iCaptionInteractorStyle();

private:

	iCaptionInteractorStyle(iViewModule *vm);

	iCaption *mInteractionCaption;
};

#endif // ICAPTIONINTERACTORSTYLE_H
